from django.urls import re_path, include
from rest_framework import routers
from . import views

ROUTER = routers.DefaultRouter()
ROUTER.register(r'engines', views.EngineViewSet, base_name='engine')
ROUTER.register(r'scales', views.ScaleViewSet, base_name='scale')
ROUTER.register(r'clusters', views.ClusterViewSet, base_name='cluster')
ROUTER.register(r'clusteroperations', views.ClusterOperationViewSet, base_name='clusteroperation')

urlpatterns = [
    re_path(r'^', include(ROUTER.urls)),
]



from ambari.client import Client

def get_engine_host(portal, engine):
    c=Client(portal)
    return c.cluster.hosts[-1].name

def list_engines(portal):
    return Client(portal).stack.services

def list_components(portal,engine):
    c=Client(portal)
    return c.stack.get_service(engine).components

def get_metrics(portal):
    c=Client(portal)
    m=[]
    for h in c.cluster.hosts:
        m.append({h.name: h.metrics})
    return m
